import { visit } from 'unist-util-visit';
import { toString } from 'hast-util-to-string';

function ClassList (node) {
  if (!node.properties.className) {
    node.properties.className = [];
  }
  var tokens = node.properties.className;
  var attribute = tokens.join(' ');
  var classList = {
    add: add,
    remove: remove,
    contains: contains,
    toggle: toggle,
    replace: replace,
    item: item,
    length: tokens.length,
    toString: function () {
      return attribute
    }
  };

  function add (token) {
    if (tokens.indexOf(token) > -1) return
    tokens.push(token);
    update();
  }

  function remove (token) {
    var index = tokens.indexOf(token);
    if (index === -1) return
    tokens.splice(index, 1);
    update();
  }

  function contains (token) {
    return tokens.includes(token)
  }

  function toggle (token) {
    if (contains(token)) {
      remove(token);
      return false
    } else {
      add(token);
      return true
    }
  }

  function replace (a, b) {
    var i = tokens.indexOf(a);
    if (i > -1) tokens[i] = b;
  }

  function item (index) {
    return tokens[index] || null
  }

  function update () {
    classList.length = tokens.length;
    attribute = tokens.join(' ');
  }

  return classList
}

var hastUtilClassList = ClassList;

//@ts-ignore
function classList(node) {
    //@ts-ignore
    return hastUtilClassList(node);
}
const rehypePrismDiff = (option) => {
    return (tree) => {
        visit(tree, 'element', (node, _index, parent) => {
            if (!parent || parent.tagName !== 'pre' || !('tagName' in node) || node.tagName !== 'code') {
                return;
            }
            let meta = node.data && node.data.meta ? node.data.meta : '';
            if (!meta.toLowerCase().includes('diff'.toLowerCase()))
                return;
            classList(node).add('code-diff');
            node.children.forEach((line) => {
                if (line.type !== 'element')
                    return;
                const lineString = toString(line);
                if (lineString.substring(0, 1) === '-') {
                    classList(line).add(`diff-deleted`);
                }
                else if (lineString.substring(0, 1) === '+') {
                    classList(line).add(`diff-inserted`);
                }
                else if (lineString.substring(0, 1) === '!') {
                    classList(line).add(`diff-warn`);
                }
                else if (lineString.substring(0, 1) === '#') {
                    classList(line).add(`diff-comment`);
                }
                if (option?.remove) ;
            });
        });
    };
};

export { rehypePrismDiff as default };
//# sourceMappingURL=index.js.map
